#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# __main__.py

import sys, shutil

from dreamtools.cfgmng import CFGBases as cfgloader
from dreamtools import tools
#from source import source


def setproject ():
    """
    Intialisation du projet
    """
    import pkg_resources

    base = tools.dir_worked()
    dest= tools.path_build(base, 'cfg')

    print ('**************************************************************************')
    print('** Création architecture')
    print('** -----------------------------------------------------------------------')
    print('** Répertoire logs ')
    tools.makedirs(tools.path_build(base, 'logs'))
    print('**\t>> Répertoire créé : ', tools.path_build(base, 'logs'))
    print('** Répertoire configuration')
    src = pkg_resources.resource_filename('dreamtools', 'cfg')
    shutil.copytree(src, dest)
    print('**\t>> Répertoire créé : ', dest)
    print('**=======================================================================-')


if __name__ == "__main__":
    sys.exit(setproject())


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

import dreamtools
from dreamtools import cfgloader
from dreamtools import tools

cfg = ["cfg/*.yml"]
with open('README.md') as readme:
    long_description = readme.read()

setup(
    name= 'dreamtools-dreamgeeker',
    install_requires= ['setuptools','pyaml',
                      'requests', 'cerberus>= 1.3.2', 'pillow >= 8.0.1', 'pytz>=pytz==2020.4'
                      ],
    author= "dreamgeeker",
    author_email= "dreamgeeker@couleurwest-it.com",
    version= dreamtools.__version__,
    description= "outils de developpement de base",
    long_description= long_description,
    url='https://github.com/couleurwest/dreamgeeker-tools',
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: French",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.8",
        "Topic :: Software Development",
    ],
    packages=find_packages(),
    package_data={'dreamtools': cfg},
    include_package_data=True,
    python_requires='>=3.8',
    entry_points= {
        'console_scripts': [
            'tools-installer = scripts.__main__:setproject'
        ],
    }
)


from . import tools
from . import tracker

class CConfig():

    def __init__(self, app, mode="PROD"):
        """ Configuration des parametres d'accès relatif au projet en cours

        Parametres
        -----------
        :param str app: Nom de l'application
        :param str[PROD|DEV] mode: mode de logging

        """

        tools.APP_NAME = app
        tools.PROJECT_DIR = tools.dir_worked()
        tools.APP_DIR = tools.path_build(tools.PROJECT_DIR, tools.APP_NAME)
        tools.TMP_DIR = tools.path_build(tools.PROJECT_DIR, 'tmp')

        tracker.config(mode)



# -*- coding: utf-8 -*-
# mailbot.py

"""
Module de Gestion de mail préparés

pathfile : dreamtools/mailbot.py

Pré-Requis
-------------
.. warning::

    Indiquer les parametres smtp dans le fichiers de configuration <PROJECT_NAME>/cfg/.app.yml

.. code-block:: YAML

    smtp:
     h: smtp-host_adresse
     po: port_smtp
     m: mail_authen
     pw: password_auth
     h_s : name_sender <email>


.. warning::

    Les mails sont à définir dans le ficchier <PROJECT_NAME>/cfg/mailing.yml au format suivant

.. code-block:: YAML

     footer:
      html: <Pied de mail unique pour tous les mails (signature, rgpd...)>
      text: <Pied de mail unique pour tous les mails (signature, rgpd...)>
     code_mail:
      html: <ici mail au format HTML>
      text : <Le mail au format texte>
      objt : <Objet du mail>

Class CMailer
--------------
"""

import smtplib
import ssl
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText

from . import cfgloader, tracker


class CMailer(object):
    smtp = cfgloader.app_cfg('smtp')
    footers = cfgloader.mailing_lib('footer')

    @staticmethod
    def __send_mail(subject, receivers, d_msg, to_receiver=None):
        """ Envoie du mail

        :param subject: Sujet du mail
        :param receivers: email destinataire
        :param d_msg: Message
        :param to_receiver: Nom destinataire
        :return:
        """
        
        tracker.flag("[dreamtools.mailbot] SEND_MAIL : Parametrage smtp")
        context = ssl.create_default_context()

        tracker.flag("[dreamtools.mailbot] SEND_MAIL:Parametrage message MIME")
        message = MIMEMultipart("alternative")
        message["Subject"] = subject
        message["From"] = CMailer.smtp['h_s']
        message["To"] = to_receiver or receivers

        tracker.flag("[dreamtools.mailbot] SEND_MAIL:Parametrage contenu mail")
        content = d_msg.get('text') + CMailer.footers['txt']
        content = MIMEText(content)
        message.attach(content)

        if d_msg.get('html'):
            content = d_msg.get('html') + CMailer.footers['html']
            content = MIMEText(content, "html")
            message.attach(content)

        tracker.flag("[dreamtools.mailbot] SEND_MAIL:Coonnexion SMTP")
        with smtplib.SMTP_SSL(CMailer.smtp['h'], CMailer.smtp['po'], context=context) as server:
            tracker.flag("[dreamtools.mailbot] SEND_MAIL:Authentification")
            server.login(CMailer.smtp['m'], CMailer.smtp['pw'])
            tracker.flag("[dreamtools.mailbot] SEND_MAIL: Sending")
            server.sendmail(CMailer.smtp['m'], receivers, message.as_string())

            return True


    staticmethod
    def presend(email, code, name='', **data_field):
        """ Preparation pour envoi d'un message mail 
        
        :param str email: email destinataire
        :param str code: réfénce du mail à chargé
        :param str name: nom du destinataire
        :param dict data_field: liste de données relatif à des champs définis dans le mails

        
        """
        tracker.flag('[dreamtools.mailbot] PRESEND:Loading template {}'.format(code))
        mail = cfgloader.mailing_lib(code)
    
        tracker.flag('[dreamtools.mailbot] PRESEND: Preparation')
    
        part1 = mail['text'].format(**data_field)
        part2 = mail['html'].format(**data_field)
        to_receiver = r'{} <{mail}>'.format(name, mail=email)
    
        tracker.flag('[dreamtools.mailbot] PRESEND: Envoi ({}) -> {}'.format(code, email))
        send = tracker.fntracker(CMailer.__send_mail, 'Envoi ({}) -> {}'.format(code, email), mail.get('objt'),
                                 email, {'text': part1, 'html': part2}, to_receiver)

        return send.ok

__all__ = ['CMailer']
